Class: Google::Apis::CloudtasksV2beta3::OAuthToken

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudtasks_v2beta3/classes.rb,
lib/google/apis/cloudtasks_v2beta3/representations.rb,
lib/google/apis/cloudtasks_v2beta3/representations.rb

Overview

Contains information needed for generating an OAuth token. This type of authorization should generally only be used when calling Google APIs hosted on *.googleapis.com.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OAuthToken

Returns a new instance of OAuthToken.



1090
1091
1092
# File 'lib/google/apis/cloudtasks_v2beta3/classes.rb', line 1090

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#scopeString

OAuth scope to be used for generating OAuth access token. If not specified, " https://www.googleapis.com/auth/cloud-platform" will be used. Corresponds to the JSON property scope

Returns:

  • (String)


1080
1081
1082
# File 'lib/google/apis/cloudtasks_v2beta3/classes.rb', line 1080

def scope
  @scope
end

#service_account_emailString

Service account email to be used for generating OAuth token. The service account must be within the same project as the queue. The caller must have iam.serviceAccounts.actAs permission for the service account. Corresponds to the JSON property serviceAccountEmail

Returns:

  • (String)


1088
1089
1090
# File 'lib/google/apis/cloudtasks_v2beta3/classes.rb', line 1088

def 
  @service_account_email
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1095
1096
1097
1098
# File 'lib/google/apis/cloudtasks_v2beta3/classes.rb', line 1095

def update!(**args)
  @scope = args[:scope] if args.key?(:scope)
  @service_account_email = args[:service_account_email] if args.key?(:service_account_email)
end