Class: Google::Apis::CloudtasksV2beta3::QueueStats
- Inherits:
-
Object
- Object
- Google::Apis::CloudtasksV2beta3::QueueStats
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudtasks_v2beta3/classes.rb,
lib/google/apis/cloudtasks_v2beta3/representations.rb,
lib/google/apis/cloudtasks_v2beta3/representations.rb
Overview
Statistics for a queue.
Instance Attribute Summary collapse
-
#concurrent_dispatches_count ⇒ Fixnum
Output only.
-
#effective_execution_rate ⇒ Float
Output only.
-
#executed_last_minute_count ⇒ Fixnum
Output only.
-
#oldest_estimated_arrival_time ⇒ String
Output only.
-
#tasks_count ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ QueueStats
constructor
A new instance of QueueStats.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ QueueStats
Returns a new instance of QueueStats.
1560 1561 1562 |
# File 'lib/google/apis/cloudtasks_v2beta3/classes.rb', line 1560 def initialize(**args) update!(**args) end |
Instance Attribute Details
#concurrent_dispatches_count ⇒ Fixnum
Output only. The number of requests that the queue has dispatched but has not
received a reply for yet.
Corresponds to the JSON property concurrentDispatchesCount
1529 1530 1531 |
# File 'lib/google/apis/cloudtasks_v2beta3/classes.rb', line 1529 def concurrent_dispatches_count @concurrent_dispatches_count end |
#effective_execution_rate ⇒ Float
Output only. The current maximum number of tasks per second executed by the
queue. The maximum value of this variable is controlled by the RateLimits of
the Queue. However, this value could be less to avoid overloading the
endpoints tasks in the queue are targeting.
Corresponds to the JSON property effectiveExecutionRate
1537 1538 1539 |
# File 'lib/google/apis/cloudtasks_v2beta3/classes.rb', line 1537 def effective_execution_rate @effective_execution_rate end |
#executed_last_minute_count ⇒ Fixnum
Output only. The number of tasks that the queue has dispatched and received a
reply for during the last minute. This variable counts both successful and non-
successful executions.
Corresponds to the JSON property executedLastMinuteCount
1544 1545 1546 |
# File 'lib/google/apis/cloudtasks_v2beta3/classes.rb', line 1544 def executed_last_minute_count @executed_last_minute_count end |
#oldest_estimated_arrival_time ⇒ String
Output only. An estimation of the nearest time in the future where a task in
the queue is scheduled to be executed.
Corresponds to the JSON property oldestEstimatedArrivalTime
1550 1551 1552 |
# File 'lib/google/apis/cloudtasks_v2beta3/classes.rb', line 1550 def oldest_estimated_arrival_time @oldest_estimated_arrival_time end |
#tasks_count ⇒ Fixnum
Output only. An estimation of the number of tasks in the queue, that is, the
tasks in the queue that haven't been executed, the tasks in the queue which
the queue has dispatched but has not yet received a reply for, and the failed
tasks that the queue is retrying.
Corresponds to the JSON property tasksCount
1558 1559 1560 |
# File 'lib/google/apis/cloudtasks_v2beta3/classes.rb', line 1558 def tasks_count @tasks_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1565 1566 1567 1568 1569 1570 1571 |
# File 'lib/google/apis/cloudtasks_v2beta3/classes.rb', line 1565 def update!(**args) @concurrent_dispatches_count = args[:concurrent_dispatches_count] if args.key?(:concurrent_dispatches_count) @effective_execution_rate = args[:effective_execution_rate] if args.key?(:effective_execution_rate) @executed_last_minute_count = args[:executed_last_minute_count] if args.key?(:executed_last_minute_count) @oldest_estimated_arrival_time = args[:oldest_estimated_arrival_time] if args.key?(:oldest_estimated_arrival_time) @tasks_count = args[:tasks_count] if args.key?(:tasks_count) end |