Class: Google::Apis::CloudtasksV2beta3::RetryConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudtasks_v2beta3/classes.rb,
lib/google/apis/cloudtasks_v2beta3/representations.rb,
lib/google/apis/cloudtasks_v2beta3/representations.rb

Overview

Retry config. These settings determine when a failed task attempt is retried.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RetryConfig

Returns a new instance of RetryConfig.



1602
1603
1604
# File 'lib/google/apis/cloudtasks_v2beta3/classes.rb', line 1602

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_attemptsFixnum

Number of attempts per task, including the first attempt. (If the first attempt fails, there will be max_attempts - 1 retries.) Must be greater than or equal to -1, which indicates unlimited attempts. Cloud Tasks stops retrying only when max_attempts and max_retry_duration are both satisfied, or when the task is successfully executed. When the task has been attempted max_attempts times and when the max_retry_duration time has passed, no further attempts are made, and the task is deleted. If max_attempts is set to -1 and max_retry_duration is set to 0, the task is retried until the maximum task retention limit is reached. If unspecified when the queue is created, Cloud Tasks will pick the default. This field has the same meaning as task_retry_limit in queue.yaml/xml. Corresponds to the JSON property maxAttempts

Returns:

  • (Fixnum)


1538
1539
1540
# File 'lib/google/apis/cloudtasks_v2beta3/classes.rb', line 1538

def max_attempts
  @max_attempts
end

#max_backoffString

A task will be scheduled for retry between min_backoff and max_backoff duration after it fails, if the queue's RetryConfig specifies that the task should be retried. The value must be given as a string that indicates the length of time (in seconds) followed by s (for "seconds"). For more information on the format, see the documentation for Duration. max_backoff will be truncated to the nearest second. If unspecified when the queue is created, Cloud Tasks will pick the default. This field has the same meaning as max_backoff_seconds in queue.yaml/xml. Corresponds to the JSON property maxBackoff

Returns:

  • (String)


1552
1553
1554
# File 'lib/google/apis/cloudtasks_v2beta3/classes.rb', line 1552

def max_backoff
  @max_backoff
end

#max_doublingsFixnum

The time between retries will double max_doublings times. A task's retry interval starts at min_backoff, then doubles max_doublings times, then increases linearly, and finally retries at intervals of max_backoff up to max_attempts times. For example, if min_backoff is 10s, max_backoff is 300s, and max_doublings is 3, then the a task will first be retried in 10s. The retry interval will double three times, and then increase linearly by 2^3 * 10s. Finally, the task will retry at intervals of max_backoff until the task has been attempted max_attempts times. Thus, the requests will retry at 10s, 20s, 40s, 80s, 160s, 240s, 300s, 300s, .... If unspecified when the queue is created, Cloud Tasks will pick the default. This field has the same meaning as max_doublings in queue.yaml/xml. Corresponds to the JSON property maxDoublings

Returns:

  • (Fixnum)


1568
1569
1570
# File 'lib/google/apis/cloudtasks_v2beta3/classes.rb', line 1568

def max_doublings
  @max_doublings
end

#max_retry_durationString

If positive, max_retry_duration specifies the time limit for retrying a failed task, measured from when the task was first attempted. Once max_retry_duration time has passed and the task has been attempted max_attempts times, no further attempts are made and the task is deleted. A zero (0) indicates an unlimited duration, up to the maximum task retention limit. The value must be given as a string that indicates the length of time (in seconds) followed by s (for "seconds"). For the maximum possible value or the format, see the documentation for Duration. max_retry_duration will be truncated to the nearest second. If unspecified when the queue is created, Cloud Tasks will pick the default. This field has the same meaning as task_age_limit in queue.yaml/xml. Corresponds to the JSON property maxRetryDuration

Returns:

  • (String)


1586
1587
1588
# File 'lib/google/apis/cloudtasks_v2beta3/classes.rb', line 1586

def max_retry_duration
  @max_retry_duration
end

#min_backoffString

A task will be scheduled for retry between min_backoff and max_backoff duration after it fails, if the queue's RetryConfig specifies that the task should be retried. The value must be given as a string that indicates the length of time (in seconds) followed by s (for "seconds"). For more information on the format, see the documentation for Duration. min_backoff will be truncated to the nearest second. If unspecified when the queue is created, Cloud Tasks will pick the default. This field has the same meaning as min_backoff_seconds in queue.yaml/xml. Corresponds to the JSON property minBackoff

Returns:

  • (String)


1600
1601
1602
# File 'lib/google/apis/cloudtasks_v2beta3/classes.rb', line 1600

def min_backoff
  @min_backoff
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1607
1608
1609
1610
1611
1612
1613
# File 'lib/google/apis/cloudtasks_v2beta3/classes.rb', line 1607

def update!(**args)
  @max_attempts = args[:max_attempts] if args.key?(:max_attempts)
  @max_backoff = args[:max_backoff] if args.key?(:max_backoff)
  @max_doublings = args[:max_doublings] if args.key?(:max_doublings)
  @max_retry_duration = args[:max_retry_duration] if args.key?(:max_retry_duration)
  @min_backoff = args[:min_backoff] if args.key?(:min_backoff)
end