Class: Google::Apis::CloudtasksV2beta3::RunTaskRequest
- Inherits:
-
Object
- Object
- Google::Apis::CloudtasksV2beta3::RunTaskRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudtasks_v2beta3/classes.rb,
lib/google/apis/cloudtasks_v2beta3/representations.rb,
lib/google/apis/cloudtasks_v2beta3/representations.rb
Overview
Request message for forcing a task to run now using RunTask.
Instance Attribute Summary collapse
-
#response_view ⇒ String
The response_view specifies which subset of the Task will be returned.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RunTaskRequest
constructor
A new instance of RunTaskRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RunTaskRequest
Returns a new instance of RunTaskRequest.
1630 1631 1632 |
# File 'lib/google/apis/cloudtasks_v2beta3/classes.rb', line 1630 def initialize(**args) update!(**args) end |
Instance Attribute Details
#response_view ⇒ String
The response_view specifies which subset of the Task will be returned. By
default response_view is BASIC; not all information is retrieved by default
because some data, such as payloads, might be desirable to return only when
needed because of its large size or because of the sensitivity of data that it
contains. Authorization for FULL requires cloudtasks.tasks.fullView Google
IAM permission on the Task resource.
Corresponds to the JSON property responseView
1628 1629 1630 |
# File 'lib/google/apis/cloudtasks_v2beta3/classes.rb', line 1628 def response_view @response_view end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1635 1636 1637 |
# File 'lib/google/apis/cloudtasks_v2beta3/classes.rb', line 1635 def update!(**args) @response_view = args[:response_view] if args.key?(:response_view) end |