Class: Google::Apis::CloudtasksV2beta3::BatchCreateTasksRequest
- Inherits:
-
Object
- Object
- Google::Apis::CloudtasksV2beta3::BatchCreateTasksRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudtasks_v2beta3/classes.rb,
lib/google/apis/cloudtasks_v2beta3/representations.rb,
lib/google/apis/cloudtasks_v2beta3/representations.rb
Overview
Request message for [BatchCreateTasks].
Instance Attribute Summary collapse
-
#request_id ⇒ String
Optional.
-
#requests ⇒ Array<Google::Apis::CloudtasksV2beta3::CreateTaskRequest>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BatchCreateTasksRequest
constructor
A new instance of BatchCreateTasksRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BatchCreateTasksRequest
Returns a new instance of BatchCreateTasksRequest.
308 309 310 |
# File 'lib/google/apis/cloudtasks_v2beta3/classes.rb', line 308 def initialize(**args) update!(**args) end |
Instance Attribute Details
#request_id ⇒ String
Optional. This field will be used to identify the long running operation,
avoiding duplication when user retries. If not provided, then a UUID will be
generated at server side.
Corresponds to the JSON property requestId
297 298 299 |
# File 'lib/google/apis/cloudtasks_v2beta3/classes.rb', line 297 def request_id @request_id end |
#requests ⇒ Array<Google::Apis::CloudtasksV2beta3::CreateTaskRequest>
Required. The list of requests to create tasks. The queue specified in parent
field of each CreateTaskRequest will be the same. This validation happens on
the client side as well as in the handler. BatchCreateTasksRequest.parent will
also be the same value as the individual CreateTaskRequest.parent . The
maximum number of requests is 100.
Corresponds to the JSON property requests
306 307 308 |
# File 'lib/google/apis/cloudtasks_v2beta3/classes.rb', line 306 def requests @requests end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
313 314 315 316 |
# File 'lib/google/apis/cloudtasks_v2beta3/classes.rb', line 313 def update!(**args) @request_id = args[:request_id] if args.key?(:request_id) @requests = args[:requests] if args.key?(:requests) end |