Class: Google::Apis::CloudtasksV2beta3::CloudTasksService
- Inherits:
-
Google::Apis::Core::BaseService
- Object
- Google::Apis::Core::BaseService
- Google::Apis::CloudtasksV2beta3::CloudTasksService
- Defined in:
- lib/google/apis/cloudtasks_v2beta3/service.rb
Overview
Cloud Tasks API
Manages the execution of large numbers of distributed requests.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://cloudtasks.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#buffer_task(queue, task_id, buffer_task_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta3::BufferTaskResponse
Creates and buffers a new task without the need to explicitly define a Task message.
-
#create_project_location_queue(parent, queue_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta3::Queue
Creates a queue.
-
#create_task(parent, create_task_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta3::Task
Creates a task and adds it to a queue.
-
#delete_project_location_queue(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta3::Empty
Deletes a queue.
-
#delete_project_location_queue_task(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta3::Empty
Deletes a task.
-
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta3::Location
Gets information about a location.
-
#get_project_location_cmek_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta3::CmekConfig
Gets the CMEK config.
-
#get_project_location_queue(name, read_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta3::Queue
Gets a queue.
-
#get_project_location_queue_task(name, response_view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta3::Task
Gets a task.
-
#get_queue_iam_policy(resource, get_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta3::Policy
Gets the access control policy for a Queue.
-
#initialize ⇒ CloudTasksService
constructor
A new instance of CloudTasksService.
-
#list_project_location_queue_tasks(parent, page_size: nil, page_token: nil, response_view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta3::ListTasksResponse
Lists the tasks in a queue.
-
#list_project_location_queues(parent, filter: nil, page_size: nil, page_token: nil, read_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta3::ListQueuesResponse
Lists queues.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta3::ListLocationsResponse
Lists information about the supported locations for this service.
-
#patch_project_location_queue(name, queue_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta3::Queue
Updates a queue.
-
#pause_queue(name, pause_queue_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta3::Queue
Pauses the queue.
-
#purge_queue(name, purge_queue_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta3::Queue
Purges a queue by deleting all of its tasks.
-
#resume_queue(name, resume_queue_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta3::Queue
Resume a queue.
-
#run_task(name, run_task_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta3::Task
Forces a task to run now.
-
#set_queue_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta3::Policy
Sets the access control policy for a Queue.
-
#test_queue_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta3::TestIamPermissionsResponse
Returns permissions that a caller has on a Queue.
-
#update_project_location_cmek_config(name, cmek_config_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta3::CmekConfig
Creates or Updates a CMEK config.
Constructor Details
#initialize ⇒ CloudTasksService
Returns a new instance of CloudTasksService.
47 48 49 50 51 52 |
# File 'lib/google/apis/cloudtasks_v2beta3/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-cloudtasks_v2beta3', client_version: Google::Apis::CloudtasksV2beta3::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/cloudtasks_v2beta3/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/cloudtasks_v2beta3/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#buffer_task(queue, task_id, buffer_task_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta3::BufferTaskResponse
Creates and buffers a new task without the need to explicitly define a Task message. The queue must have HTTP target. To create the task with a custom ID, use the following format and set TASK_ID to your desired ID: projects/ PROJECT_ID/locations/LOCATION_ID/queues/QUEUE_ID/tasks/TASK_ID:buffer To create the task with an automatically generated ID, use the following format: projects/PROJECT_ID/locations/LOCATION_ID/queues/QUEUE_ID/tasks:buffer.
704 705 706 707 708 709 710 711 712 713 714 715 |
# File 'lib/google/apis/cloudtasks_v2beta3/service.rb', line 704 def buffer_task(queue, task_id, buffer_task_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2beta3/{+queue}/tasks/{taskId}:buffer', ) command.request_representation = Google::Apis::CloudtasksV2beta3::BufferTaskRequest::Representation command.request_object = buffer_task_request_object command.response_representation = Google::Apis::CloudtasksV2beta3::BufferTaskResponse::Representation command.response_class = Google::Apis::CloudtasksV2beta3::BufferTaskResponse command.params['queue'] = queue unless queue.nil? command.params['taskId'] = task_id unless task_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_queue(parent, queue_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta3::Queue
Creates a queue. Queues created with this method allow tasks to live for a
maximum of 31 days. After a task is 31 days old, the task will be deleted
regardless of whether it was dispatched or not. WARNING: Using this method may
have unintended side effects if you are using an App Engine queue.yaml or
queue.xml file to manage your queues. Read Overview of Queue Management and
queue.yaml before using this
method.
242 243 244 245 246 247 248 249 250 251 252 |
# File 'lib/google/apis/cloudtasks_v2beta3/service.rb', line 242 def create_project_location_queue(parent, queue_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2beta3/{+parent}/queues', ) command.request_representation = Google::Apis::CloudtasksV2beta3::Queue::Representation command.request_object = queue_object command.response_representation = Google::Apis::CloudtasksV2beta3::Queue::Representation command.response_class = Google::Apis::CloudtasksV2beta3::Queue command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_task(parent, create_task_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta3::Task
Creates a task and adds it to a queue. Tasks cannot be updated after creation; there is no UpdateTask command. * The maximum task size is 100KB.
740 741 742 743 744 745 746 747 748 749 750 |
# File 'lib/google/apis/cloudtasks_v2beta3/service.rb', line 740 def create_task(parent, create_task_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2beta3/{+parent}/tasks', ) command.request_representation = Google::Apis::CloudtasksV2beta3::CreateTaskRequest::Representation command.request_object = create_task_request_object command.response_representation = Google::Apis::CloudtasksV2beta3::Task::Representation command.response_class = Google::Apis::CloudtasksV2beta3::Task command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_queue(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta3::Empty
Deletes a queue. This command will delete the queue even if it has tasks in it.
Note : If you delete a queue, you may be prevented from creating a new queue
with the same name as the deleted queue for a tombstone window of up to 3 days.
During this window, the CreateQueue operation may appear to recreate the
queue, but this can be misleading. If you attempt to create a queue with the
same name as one that is in the tombstone window, run GetQueue to confirm that
the queue creation was successful. If GetQueue returns 200 response code, your
queue was successfully created with the name of the previously deleted queue.
Otherwise, your queue did not successfully recreate. WARNING: Using this
method may have unintended side effects if you are using an App Engine queue.
yaml or queue.xml file to manage your queues. Read Overview of Queue
Management and queue.yaml
before using this method.
287 288 289 290 291 292 293 294 295 |
# File 'lib/google/apis/cloudtasks_v2beta3/service.rb', line 287 def delete_project_location_queue(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v2beta3/{+name}', ) command.response_representation = Google::Apis::CloudtasksV2beta3::Empty::Representation command.response_class = Google::Apis::CloudtasksV2beta3::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_queue_task(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta3::Empty
Deletes a task. A task can be deleted if it is scheduled or dispatched. A task cannot be deleted if it has executed successfully or permanently failed.
774 775 776 777 778 779 780 781 782 |
# File 'lib/google/apis/cloudtasks_v2beta3/service.rb', line 774 def delete_project_location_queue_task(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v2beta3/{+name}', ) command.response_representation = Google::Apis::CloudtasksV2beta3::Empty::Representation command.response_class = Google::Apis::CloudtasksV2beta3::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta3::Location
Gets information about a location.
74 75 76 77 78 79 80 81 82 |
# File 'lib/google/apis/cloudtasks_v2beta3/service.rb', line 74 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2beta3/{+name}', ) command.response_representation = Google::Apis::CloudtasksV2beta3::Location::Representation command.response_class = Google::Apis::CloudtasksV2beta3::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_cmek_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta3::CmekConfig
Gets the CMEK config. Gets the Customer Managed Encryption Key configured with the Cloud Tasks lcoation. By default there is no kms_key configured.
106 107 108 109 110 111 112 113 114 |
# File 'lib/google/apis/cloudtasks_v2beta3/service.rb', line 106 def get_project_location_cmek_config(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2beta3/{+name}', ) command.response_representation = Google::Apis::CloudtasksV2beta3::CmekConfig::Representation command.response_class = Google::Apis::CloudtasksV2beta3::CmekConfig command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_queue(name, read_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta3::Queue
Gets a queue.
323 324 325 326 327 328 329 330 331 332 |
# File 'lib/google/apis/cloudtasks_v2beta3/service.rb', line 323 def get_project_location_queue(name, read_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2beta3/{+name}', ) command.response_representation = Google::Apis::CloudtasksV2beta3::Queue::Representation command.response_class = Google::Apis::CloudtasksV2beta3::Queue command.params['name'] = name unless name.nil? command.query['readMask'] = read_mask unless read_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_queue_task(name, response_view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta3::Task
Gets a task. After a task is successfully executed or has exhausted its retry
attempts, the task is deleted. A GetTask request for a deleted task returns
a NOT_FOUND error.
814 815 816 817 818 819 820 821 822 823 |
# File 'lib/google/apis/cloudtasks_v2beta3/service.rb', line 814 def get_project_location_queue_task(name, response_view: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2beta3/{+name}', ) command.response_representation = Google::Apis::CloudtasksV2beta3::Task::Representation command.response_class = Google::Apis::CloudtasksV2beta3::Task command.params['name'] = name unless name.nil? command.query['responseView'] = response_view unless response_view.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_queue_iam_policy(resource, get_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta3::Policy
Gets the access control policy for a Queue. Returns an empty policy if the
resource exists and does not have a policy set. Authorization requires the
following Google IAM permission on the
specified resource parent: * cloudtasks.queues.getIamPolicy
360 361 362 363 364 365 366 367 368 369 370 |
# File 'lib/google/apis/cloudtasks_v2beta3/service.rb', line 360 def get_queue_iam_policy(resource, get_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2beta3/{+resource}:getIamPolicy', ) command.request_representation = Google::Apis::CloudtasksV2beta3::GetIamPolicyRequest::Representation command.request_object = get_iam_policy_request_object command.response_representation = Google::Apis::CloudtasksV2beta3::Policy::Representation command.response_class = Google::Apis::CloudtasksV2beta3::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_queue_tasks(parent, page_size: nil, page_token: nil, response_view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta3::ListTasksResponse
Lists the tasks in a queue. By default, only the BASIC view is retrieved due to performance considerations; response_view controls the subset of information which is returned. The tasks may be returned in any order. The ordering may change at any time.
866 867 868 869 870 871 872 873 874 875 876 877 |
# File 'lib/google/apis/cloudtasks_v2beta3/service.rb', line 866 def list_project_location_queue_tasks(parent, page_size: nil, page_token: nil, response_view: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2beta3/{+parent}/tasks', ) command.response_representation = Google::Apis::CloudtasksV2beta3::ListTasksResponse::Representation command.response_class = Google::Apis::CloudtasksV2beta3::ListTasksResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['responseView'] = response_view unless response_view.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_queues(parent, filter: nil, page_size: nil, page_token: nil, read_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta3::ListQueuesResponse
Lists queues. Queues are returned in lexicographical order.
416 417 418 419 420 421 422 423 424 425 426 427 428 |
# File 'lib/google/apis/cloudtasks_v2beta3/service.rb', line 416 def list_project_location_queues(parent, filter: nil, page_size: nil, page_token: nil, read_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2beta3/{+parent}/queues', ) command.response_representation = Google::Apis::CloudtasksV2beta3::ListQueuesResponse::Representation command.response_class = Google::Apis::CloudtasksV2beta3::ListQueuesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['readMask'] = read_mask unless read_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta3::ListLocationsResponse
Lists information about the supported locations for this service. This method
lists locations based on the resource scope provided in the [
ListLocationsRequest.name] field: * Global locations: If name is empty,
the method lists the public locations available to all projects. * Project-
specific locations: If name follows the format projects/project`, the
method lists locations visible to that specific project. This includes public,
private, or other project-specific locations enabled for the project. For gRPC
and client library implementations, the resource name is passed as thename`
field. For direct service calls, the resource name is incorporated into the
request path based on the specific service implementation and version.
158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/google/apis/cloudtasks_v2beta3/service.rb', line 158 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2beta3/{+name}/locations', ) command.response_representation = Google::Apis::CloudtasksV2beta3::ListLocationsResponse::Representation command.response_class = Google::Apis::CloudtasksV2beta3::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_queue(name, queue_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta3::Queue
Updates a queue. This method creates the queue if it does not exist and
updates the queue if it does exist. Queues created with this method allow
tasks to live for a maximum of 31 days. After a task is 31 days old, the task
will be deleted regardless of whether it was dispatched or not. WARNING: Using
this method may have unintended side effects if you are using an App Engine
queue.yaml or queue.xml file to manage your queues. Read Overview of Queue
Management and queue.yaml
before using this method.
471 472 473 474 475 476 477 478 479 480 481 482 |
# File 'lib/google/apis/cloudtasks_v2beta3/service.rb', line 471 def patch_project_location_queue(name, queue_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v2beta3/{+name}', ) command.request_representation = Google::Apis::CloudtasksV2beta3::Queue::Representation command.request_object = queue_object command.response_representation = Google::Apis::CloudtasksV2beta3::Queue::Representation command.response_class = Google::Apis::CloudtasksV2beta3::Queue command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#pause_queue(name, pause_queue_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta3::Queue
Pauses the queue. If a queue is paused then the system will stop dispatching tasks until the queue is resumed via ResumeQueue. Tasks can still be added when the queue is paused. A queue is paused if its state is PAUSED.
508 509 510 511 512 513 514 515 516 517 518 |
# File 'lib/google/apis/cloudtasks_v2beta3/service.rb', line 508 def pause_queue(name, pause_queue_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2beta3/{+name}:pause', ) command.request_representation = Google::Apis::CloudtasksV2beta3::PauseQueueRequest::Representation command.request_object = pause_queue_request_object command.response_representation = Google::Apis::CloudtasksV2beta3::Queue::Representation command.response_class = Google::Apis::CloudtasksV2beta3::Queue command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#purge_queue(name, purge_queue_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta3::Queue
Purges a queue by deleting all of its tasks. All tasks created before this method is called are permanently deleted. Purge operations can take up to one minute to take effect. Tasks might be dispatched before the purge takes effect. A purge is irreversible.
545 546 547 548 549 550 551 552 553 554 555 |
# File 'lib/google/apis/cloudtasks_v2beta3/service.rb', line 545 def purge_queue(name, purge_queue_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2beta3/{+name}:purge', ) command.request_representation = Google::Apis::CloudtasksV2beta3::PurgeQueueRequest::Representation command.request_object = purge_queue_request_object command.response_representation = Google::Apis::CloudtasksV2beta3::Queue::Representation command.response_class = Google::Apis::CloudtasksV2beta3::Queue command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#resume_queue(name, resume_queue_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta3::Queue
Resume a queue. This method resumes a queue after it has been PAUSED or DISABLED. The state of a queue is stored in the queue's state; after calling this method it will be set to RUNNING. WARNING: Resuming many high-QPS queues at the same time can lead to target overloading. If you are resuming high-QPS queues, follow the 500/50/5 pattern described in Managing Cloud Tasks Scaling Risks.
584 585 586 587 588 589 590 591 592 593 594 |
# File 'lib/google/apis/cloudtasks_v2beta3/service.rb', line 584 def resume_queue(name, resume_queue_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2beta3/{+name}:resume', ) command.request_representation = Google::Apis::CloudtasksV2beta3::ResumeQueueRequest::Representation command.request_object = resume_queue_request_object command.response_representation = Google::Apis::CloudtasksV2beta3::Queue::Representation command.response_class = Google::Apis::CloudtasksV2beta3::Queue command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#run_task(name, run_task_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta3::Task
Forces a task to run now. When this method is called, Cloud Tasks will dispatch the task, even if the task is already running, the queue has reached its RateLimits or is PAUSED. This command is meant to be used for manual debugging. For example, RunTask can be used to retry a failed task after a fix has been made or to manually force a task to be dispatched now. The dispatched task is returned. That is, the task that is returned contains the status after the task is dispatched but before the task is received by its target. If Cloud Tasks receives a successful response from the task's target, then the task will be deleted; otherwise the task's schedule_time will be reset to the time that RunTask was called plus the retry delay specified in the queue's RetryConfig. RunTask returns NOT_FOUND when it is called on a task that has already succeeded or permanently failed.
912 913 914 915 916 917 918 919 920 921 922 |
# File 'lib/google/apis/cloudtasks_v2beta3/service.rb', line 912 def run_task(name, run_task_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2beta3/{+name}:run', ) command.request_representation = Google::Apis::CloudtasksV2beta3::RunTaskRequest::Representation command.request_object = run_task_request_object command.response_representation = Google::Apis::CloudtasksV2beta3::Task::Representation command.response_class = Google::Apis::CloudtasksV2beta3::Task command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_queue_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta3::Policy
Sets the access control policy for a Queue. Replaces any existing policy. Note:
The Cloud Console does not check queue-level IAM permissions yet. Project-
level permissions are required to use the Cloud Console. Authorization
requires the following Google IAM permission
on the specified resource parent: * cloudtasks.queues.setIamPolicy
623 624 625 626 627 628 629 630 631 632 633 |
# File 'lib/google/apis/cloudtasks_v2beta3/service.rb', line 623 def set_queue_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2beta3/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::CloudtasksV2beta3::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::CloudtasksV2beta3::Policy::Representation command.response_class = Google::Apis::CloudtasksV2beta3::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_queue_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta3::TestIamPermissionsResponse
Returns permissions that a caller has on a Queue. If the resource does not exist, this will return an empty set of permissions, not a NOT_FOUND error. Note: This operation is designed to be used for building permission-aware UIs and command-line tools, not for authorization checking. This operation may " fail open" without warning.
662 663 664 665 666 667 668 669 670 671 672 |
# File 'lib/google/apis/cloudtasks_v2beta3/service.rb', line 662 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2beta3/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::CloudtasksV2beta3::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::CloudtasksV2beta3::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::CloudtasksV2beta3::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#update_project_location_cmek_config(name, cmek_config_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta3::CmekConfig
Creates or Updates a CMEK config. Updates the Customer Managed Encryption Key associated with the Cloud Tasks location (Creates if the key does not already exist). All new tasks created in the location will be encrypted at-rest with the KMS-key provided in the config.
200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/google/apis/cloudtasks_v2beta3/service.rb', line 200 def update_project_location_cmek_config(name, cmek_config_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v2beta3/{+name}', ) command.request_representation = Google::Apis::CloudtasksV2beta3::CmekConfig::Representation command.request_object = cmek_config_object command.response_representation = Google::Apis::CloudtasksV2beta3::CmekConfig::Representation command.response_class = Google::Apis::CloudtasksV2beta3::CmekConfig command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |