Class: Google::Apis::CloudtasksV2beta3::StackdriverLoggingConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudtasks_v2beta3/classes.rb,
lib/google/apis/cloudtasks_v2beta3/representations.rb,
lib/google/apis/cloudtasks_v2beta3/representations.rb

Overview

Configuration options for writing logs to Stackdriver Logging.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StackdriverLoggingConfig

Returns a new instance of StackdriverLoggingConfig.



1697
1698
1699
# File 'lib/google/apis/cloudtasks_v2beta3/classes.rb', line 1697

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#sampling_ratioFloat

Specifies the fraction of operations to write to Stackdriver Logging. This field may contain any value between 0.0 and 1.0, inclusive. 0.0 is the default and means that no operations are logged. Corresponds to the JSON property samplingRatio

Returns:

  • (Float)


1695
1696
1697
# File 'lib/google/apis/cloudtasks_v2beta3/classes.rb', line 1695

def sampling_ratio
  @sampling_ratio
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1702
1703
1704
# File 'lib/google/apis/cloudtasks_v2beta3/classes.rb', line 1702

def update!(**args)
  @sampling_ratio = args[:sampling_ratio] if args.key?(:sampling_ratio)
end