Class: Google::Apis::CloudtasksV2beta3::UriOverride

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudtasks_v2beta3/classes.rb,
lib/google/apis/cloudtasks_v2beta3/representations.rb,
lib/google/apis/cloudtasks_v2beta3/representations.rb

Overview

URI Override. When specified, all the HTTP tasks inside the queue will be partially or fully overridden depending on the configured values.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UriOverride

Returns a new instance of UriOverride.



2005
2006
2007
# File 'lib/google/apis/cloudtasks_v2beta3/classes.rb', line 2005

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#hostString

Host override. When specified, replaces the host part of the task URL. For example, if the task URL is "https://www.google.com," and host value is set to "example.net", the overridden URI will be changed to "https://example.net." Host value cannot be an empty string (INVALID_ARGUMENT). Corresponds to the JSON property host

Returns:

  • (String)


1972
1973
1974
# File 'lib/google/apis/cloudtasks_v2beta3/classes.rb', line 1972

def host
  @host
end

#path_overrideGoogle::Apis::CloudtasksV2beta3::PathOverride

PathOverride. Path message defines path override for HTTP targets. Corresponds to the JSON property pathOverride



1977
1978
1979
# File 'lib/google/apis/cloudtasks_v2beta3/classes.rb', line 1977

def path_override
  @path_override
end

#portFixnum

Port override. When specified, replaces the port part of the task URI. For instance, for a URI "https://www.example.com/example" and port=123, the overridden URI becomes "https://www.example.com:123/example". Note that the port value must be a positive integer. Setting the port to 0 (Zero) clears the URI port. Corresponds to the JSON property port

Returns:

  • (Fixnum)


1986
1987
1988
# File 'lib/google/apis/cloudtasks_v2beta3/classes.rb', line 1986

def port
  @port
end

#query_overrideGoogle::Apis::CloudtasksV2beta3::QueryOverride

QueryOverride. Query message defines query override for HTTP targets. Corresponds to the JSON property queryOverride



1991
1992
1993
# File 'lib/google/apis/cloudtasks_v2beta3/classes.rb', line 1991

def query_override
  @query_override
end

#schemeString

Scheme override. When specified, the task URI scheme is replaced by the provided value (HTTP or HTTPS). Corresponds to the JSON property scheme

Returns:

  • (String)


1997
1998
1999
# File 'lib/google/apis/cloudtasks_v2beta3/classes.rb', line 1997

def scheme
  @scheme
end

#uri_override_enforce_modeString

URI Override Enforce Mode When specified, determines the Target UriOverride mode. If not specified, it defaults to ALWAYS. Corresponds to the JSON property uriOverrideEnforceMode

Returns:

  • (String)


2003
2004
2005
# File 'lib/google/apis/cloudtasks_v2beta3/classes.rb', line 2003

def uri_override_enforce_mode
  @uri_override_enforce_mode
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2010
2011
2012
2013
2014
2015
2016
2017
# File 'lib/google/apis/cloudtasks_v2beta3/classes.rb', line 2010

def update!(**args)
  @host = args[:host] if args.key?(:host)
  @path_override = args[:path_override] if args.key?(:path_override)
  @port = args[:port] if args.key?(:port)
  @query_override = args[:query_override] if args.key?(:query_override)
  @scheme = args[:scheme] if args.key?(:scheme)
  @uri_override_enforce_mode = args[:uri_override_enforce_mode] if args.key?(:uri_override_enforce_mode)
end